@@ -10,6 +10,8 @@ from xdis.opcodes.base import (
     def_op, finalize_opcodes, free_op, init_opdata,
     rm_op, update_pj3)
 
+from xdis.opcodes.opcode_3x import format_MAKE_FUNCTION_arg
+
 import xdis.opcodes.opcode_33 as opcode_33
 
 version = 3.4
@@ -27,4 +29,8 @@ free_op(l, 'LOAD_CLASSDEREF', 148)
 
 update_pj3(globals(), l)
 
+opcode_arg_fmt = {
+    'MAKE_FUNCTION': format_MAKE_FUNCTION_arg,
+}
+
 finalize_opcodes(l)
